# Generated by Django 4.2.1 on 2023-05-18 21:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0018_offermov'),
    ]

    operations = [
        migrations.CreateModel(
            name='Stat',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=120, verbose_name='Stat name')),
                ('query_text', models.TextField(help_text='Text used to execute the query', verbose_name='Query Text')),
                ('is_staff', models.BooleanField(default=True, help_text='It is required to be staff to see the stat', verbose_name='Is staff')),
                ('enabled', models.BooleanField(default=True, verbose_name='Enabled')),
            ],
            options={
                'verbose_name': 'Stat',
                'verbose_name_plural': 'Stats',
            },
        ),
    ]
